@@ -8,6 +8,7 @@
 #include <QTextBlock>
 #include <QFileDialog>
 #include <QMovie>
+#include <Phonon>
 
 
 namespace Ui {
@@ -41,6 +42,8 @@ private slots:
 
     void on_btnPlay_clicked();
 
+    void on_btnStop_clicked();
+
 private:
     Ui::MainWindow *ui;
     QNetworkAccessManager *netAccessMan;
@@ -48,6 +51,7 @@ private:
     QByteArray downloadedItem;
     QStringList *links;
     QMovie *movie;
+    Phonon::MediaObject *music;
 };
 
 #endif // MAINWINDOW_H
